@@ -1,4 +1,4 @@
-# Copyright (c) 2020, TU Wien, Department of Geodesy and Geoinformation.
+# Copyright (c) 2023, TU Wien, Department of Geodesy and Geoinformation.
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -24,11 +24,9 @@
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 """
 Base classes for reading and writing time series and images in NetCDF files
-according to the Climate Forecast Metadata Conventions
-(http://cfconventions.org/).
+using Climate Forecast Metadata Conventions (http://cfconventions.org/).
 """
 
 import os
@@ -42,8 +40,7 @@ class DatasetError(Exception):
     pass
 
 
-class Dataset(object):
-
+class Dataset:
     """
     NetCDF file wrapper class that makes some things easier
 
@@ -84,9 +81,15 @@ class Dataset(object):
         This means Fill Values will be used instead of NaN.
     """
 
-    def __init__(self, filename, name=None, file_format="NETCDF4",
-                 mode='r', zlib=True, complevel=4,
-                 autoscale=True, automask=True):
+    def __init__(self,
+                 filename,
+                 name=None,
+                 file_format="NETCDF4",
+                 mode='r',
+                 zlib=True,
+                 complevel=4,
+                 autoscale=True,
+                 automask=True):
 
         self.dataset_name = name
         self.filename = filename
@@ -111,7 +114,8 @@ class Dataset(object):
             self._create_file_dir()
 
         try:
-            self.dataset = netCDF4.Dataset(self.filename, self.mode,
+            self.dataset = netCDF4.Dataset(self.filename,
+                                           self.mode,
                                            format=self.file_format)
         except RuntimeError:
             raise IOError("File {} does not exist".format(self.filename))
@@ -155,8 +159,16 @@ class Dataset(object):
         if name not in self.dataset.dimensions.keys():
             self.dataset.createDimension(name, size=n)
 
-    def write_var(self, name, data=None, dim=None, attr={}, dtype=None,
-                  zlib=None, complevel=None, chunksizes=None, **kwargs):
+    def write_var(self,
+                  name,
+                  data=None,
+                  dim=None,
+                  attr={},
+                  dtype=None,
+                  zlib=None,
+                  complevel=None,
+                  chunksizes=None,
+                  **kwargs):
         """
         Create or overwrite values in a NetCDF variable. The data will be
         written to disk once flush or close is called
@@ -200,10 +212,14 @@ class Dataset(object):
         if name in self.dataset.variables.keys():
             var = self.dataset.variables[name]
         else:
-            var = self.dataset.createVariable(name, dtype,
-                                              dim, fill_value=fill_value,
-                                              zlib=zlib, complevel=complevel,
-                                              chunksizes=chunksizes, **kwargs)
+            var = self.dataset.createVariable(name,
+                                              dtype,
+                                              dim,
+                                              fill_value=fill_value,
+                                              zlib=zlib,
+                                              complevel=complevel,
+                                              chunksizes=chunksizes,
+                                              **kwargs)
 
         for attr_name in attr:
             attr_value = attr[attr_name]
@@ -272,22 +288,51 @@ class Dataset(object):
                 return self.dataset.variables[name][:]
 
     def add_global_attr(self, name, value):
+        """
+        Add global attribute.
+
+        Parameters
+        ----------
+        name : str
+            Name.
+        value : str or number
+            Value.
+        """
         self.global_attr[name] = value
 
     def flush(self):
+        """
+        Flush data to disk.
+        """
         if self.dataset is not None:
             if self.mode in ['w', 'r+']:
                 self._set_global_attr()
                 self.dataset.sync()
 
     def close(self):
+        """
+        Flush and close file.
+        """
         if self.dataset is not None:
             self.flush()
             self.dataset.close()
             self.dataset = None
 
     def __enter__(self):
+        """
+        ContextManager enter.
+        """
         return self
 
     def __exit__(self, value_type, value, traceback):
+        """
+        ContextManager exit.
+        """
         self.close()
+
+    def __del__(self):
+        """
+        Destructor.
+        """
+        if hasattr(self, "dataset"):
+            self.close()
