@@ -1,4 +1,4 @@
-# Copyright (c) 2020, TU Wien, Department of Geodesy and Geoinformation.
+# Copyright (c) 2023, TU Wien, Department of Geodesy and Geoinformation.
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -24,18 +24,16 @@
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 """
 Testing image classes of pynetcf.
 """
 
 import os
 import unittest
+from datetime import datetime
 from tempfile import mkdtemp
 
 import numpy as np
-from datetime import datetime
-
 import pynetcf.image as ncdata
 import pygeogrids.grids as grids
 
@@ -59,9 +57,11 @@ class ImageStackTests(unittest.TestCase):
         """
         Write/read test.
         """
-        with ncdata.ImageStack(self.testfilename, self.grid,
-                               [datetime(2007, 1, 1),
-                                datetime(2007, 1, 2)], mode="w") as nc:
+        with ncdata.ImageStack(
+                self.testfilename,
+                self.grid,
+            [datetime(2007, 1, 1), datetime(2007, 1, 2)],
+                mode="w") as nc:
             nc[14] = {'variable': [141, 142]}
             nc.write_ts([22, 23], {'variable': [[221, 222], [231, 232]]})
 
@@ -91,15 +91,17 @@ class ArrayStackTests(unittest.TestCase):
         """
         Write/read test.
         """
-        with ncdata.ArrayStack(self.testfilename, self.grid,
-                               [datetime(2007, 1, 1),
-                                datetime(2007, 1, 2)], mode="w") as nc:
+        with ncdata.ArrayStack(
+                self.testfilename,
+                self.grid,
+            [datetime(2007, 1, 1), datetime(2007, 1, 2)],
+                mode="w") as nc:
             nc[14] = {'variable': [141, 142]}
             nc.write_ts([22, 23], {'variable': [[221, 222], [231, 232]]})
 
-        with ncdata.ArrayStack(self.testfilename, self.grid,
-                               [datetime(2007, 1, 1),
-                                datetime(2007, 1, 2)]) as nc:
+        with ncdata.ArrayStack(
+                self.testfilename, self.grid,
+            [datetime(2007, 1, 1), datetime(2007, 1, 2)]) as nc:
             data = nc[14]
             assert list(data['variable'].values) == [141, 142]
             data = nc[22]
